# This file was automatically generated by SWIG (http://www.swig.org).
# Version 3.0.12
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

from sys import version_info as _swig_python_version_info
if _swig_python_version_info >= (2, 7, 0):
    def swig_import_helper():
        import importlib
        pkg = __name__.rpartition('.')[0]
        mname = '.'.join((pkg, '_medfield')).lstrip('.')
        try:
            return importlib.import_module(mname)
        except ImportError:
            return importlib.import_module('_medfield')
    _medfield = swig_import_helper()
    del swig_import_helper
elif _swig_python_version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_medfield', [dirname(__file__)])
        except ImportError:
            import _medfield
            return _medfield
        try:
            _mod = imp.load_module('_medfield', fp, pathname, description)
        finally:
            if fp is not None:
                fp.close()
        return _mod
    _medfield = swig_import_helper()
    del swig_import_helper
else:
    import _medfield
del _swig_python_version_info

try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr(self, class_type, name):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    raise AttributeError("'%s' object has no attribute '%s'" % (class_type.__name__, name))


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except __builtin__.Exception:
    class _object:
        pass
    _newclass = 0

class SwigPyIterator_medfield_module(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, SwigPyIterator_medfield_module, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, SwigPyIterator_medfield_module, name)

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _medfield.delete_SwigPyIterator_medfield_module
    __del__ = lambda self: None

    def value(self) -> "PyObject *":
        return _medfield.SwigPyIterator_medfield_module_value(self)

    def incr(self, n: 'size_t'=1) -> "swig::SwigPyIterator_medfield_module *":
        return _medfield.SwigPyIterator_medfield_module_incr(self, n)

    def decr(self, n: 'size_t'=1) -> "swig::SwigPyIterator_medfield_module *":
        return _medfield.SwigPyIterator_medfield_module_decr(self, n)

    def distance(self, x: 'SwigPyIterator_medfield_module') -> "ptrdiff_t":
        return _medfield.SwigPyIterator_medfield_module_distance(self, x)

    def equal(self, x: 'SwigPyIterator_medfield_module') -> "bool":
        return _medfield.SwigPyIterator_medfield_module_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator_medfield_module *":
        return _medfield.SwigPyIterator_medfield_module_copy(self)

    def next(self) -> "PyObject *":
        return _medfield.SwigPyIterator_medfield_module_next(self)

    def __next__(self) -> "PyObject *":
        return _medfield.SwigPyIterator_medfield_module___next__(self)

    def previous(self) -> "PyObject *":
        return _medfield.SwigPyIterator_medfield_module_previous(self)

    def advance(self, n: 'ptrdiff_t') -> "swig::SwigPyIterator_medfield_module *":
        return _medfield.SwigPyIterator_medfield_module_advance(self, n)

    def __eq__(self, x: 'SwigPyIterator_medfield_module') -> "bool":
        return _medfield.SwigPyIterator_medfield_module___eq__(self, x)

    def __ne__(self, x: 'SwigPyIterator_medfield_module') -> "bool":
        return _medfield.SwigPyIterator_medfield_module___ne__(self, x)

    def __iadd__(self, n: 'ptrdiff_t') -> "swig::SwigPyIterator_medfield_module &":
        return _medfield.SwigPyIterator_medfield_module___iadd__(self, n)

    def __isub__(self, n: 'ptrdiff_t') -> "swig::SwigPyIterator_medfield_module &":
        return _medfield.SwigPyIterator_medfield_module___isub__(self, n)

    def __add__(self, n: 'ptrdiff_t') -> "swig::SwigPyIterator_medfield_module *":
        return _medfield.SwigPyIterator_medfield_module___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _medfield.SwigPyIterator_medfield_module___sub__(self, *args)
    def __iter__(self): return self
    def __iter__(self):
        return self
SwigPyIterator_medfield_module_swigregister = _medfield.SwigPyIterator_medfield_module_swigregister
SwigPyIterator_medfield_module_swigregister(SwigPyIterator_medfield_module)

HAVE_CC_C99 = _medfield.HAVE_CC_C99
HAVE_FTIME = _medfield.HAVE_FTIME
HAVE_H5PUBLIC_H = _medfield.HAVE_H5PUBLIC_H
HAVE_INT64 = _medfield.HAVE_INT64
HAVE_INTTYPES_H = _medfield.HAVE_INTTYPES_H
HAVE_MALLOC_H = _medfield.HAVE_MALLOC_H
HAVE_MEMORY_H = _medfield.HAVE_MEMORY_H
HAVE_STDBOOL_H = _medfield.HAVE_STDBOOL_H
HAVE_STDINT_H = _medfield.HAVE_STDINT_H
HAVE_STDLIB_H = _medfield.HAVE_STDLIB_H
HAVE_STRING_H = _medfield.HAVE_STRING_H
HAVE_SYS_STAT_H = _medfield.HAVE_SYS_STAT_H
HAVE_SYS_TIMEB_H = _medfield.HAVE_SYS_TIMEB_H
HAVE_SYS_TYPES_H = _medfield.HAVE_SYS_TYPES_H
HAVE__BOOL = _medfield.HAVE__BOOL
MED_CHECK_23FORMAT = _medfield.MED_CHECK_23FORMAT
MED_HAVE_FORTRAN = _medfield.MED_HAVE_FORTRAN
MESGERR = _medfield.MESGERR
PACKAGE = _medfield.PACKAGE
PACKAGE_BUGREPORT = _medfield.PACKAGE_BUGREPORT
PACKAGE_NAME = _medfield.PACKAGE_NAME
PACKAGE_STRING = _medfield.PACKAGE_STRING
PACKAGE_URL = _medfield.PACKAGE_URL
PACKAGE_VERSION = _medfield.PACKAGE_VERSION
SIZEOF_FORTRAN_INTEGER = _medfield.SIZEOF_FORTRAN_INTEGER
SIZEOF_INT = _medfield.SIZEOF_INT
SIZEOF_LONG = _medfield.SIZEOF_LONG
STDC_HEADERS = _medfield.STDC_HEADERS
VERSION = _medfield.VERSION
HDF_VERSION_MAJOR_REF = _medfield.HDF_VERSION_MAJOR_REF
HDF_VERSION_MINOR_REF = _medfield.HDF_VERSION_MINOR_REF
HDF_VERSION_RELEASE_REF = _medfield.HDF_VERSION_RELEASE_REF
HDF_VERSION_NUM_REF = _medfield.HDF_VERSION_NUM_REF
H5F_LIBVER_18 = _medfield.H5F_LIBVER_18
MED_MAJOR_NUM = _medfield.MED_MAJOR_NUM
MED_MINOR_NUM = _medfield.MED_MINOR_NUM
MED_RELEASE_NUM = _medfield.MED_RELEASE_NUM
MED_NUM_MAJEUR = _medfield.MED_NUM_MAJEUR
MED_NUM_MINEUR = _medfield.MED_NUM_MINEUR
MED_NUM_RELEASE = _medfield.MED_NUM_RELEASE
MED_VERSION_STR = _medfield.MED_VERSION_STR
MED_MAX_PARA = _medfield.MED_MAX_PARA
MED_COMMENT_SIZE = _medfield.MED_COMMENT_SIZE
MED_IDENT_SIZE = _medfield.MED_IDENT_SIZE
MED_NAME_SIZE = _medfield.MED_NAME_SIZE
MED_SNAME_SIZE = _medfield.MED_SNAME_SIZE
MED_LNAME_SIZE = _medfield.MED_LNAME_SIZE
MED_SNAME_BLANK = _medfield.MED_SNAME_BLANK
MED_NAME_BLANK = _medfield.MED_NAME_BLANK
MED_PATHNAME_SIZE = _medfield.MED_PATHNAME_SIZE
MED_MAX_CHFID_PATH = _medfield.MED_MAX_CHFID_PATH
MED_FULL_INTERLACE = _medfield.MED_FULL_INTERLACE
MED_NO_INTERLACE = _medfield.MED_NO_INTERLACE
MED_UNDEF_INTERLACE = _medfield.MED_UNDEF_INTERLACE
MED_UNDEF_STMODE = _medfield.MED_UNDEF_STMODE
MED_GLOBAL_STMODE = _medfield.MED_GLOBAL_STMODE
MED_COMPACT_STMODE = _medfield.MED_COMPACT_STMODE
MED_GLOBAL_PFLMODE = _medfield.MED_GLOBAL_PFLMODE
MED_COMPACT_PFLMODE = _medfield.MED_COMPACT_PFLMODE
MED_UNDEF_PFLMODE = _medfield.MED_UNDEF_PFLMODE
MED_ACC_RDONLY = _medfield.MED_ACC_RDONLY
MED_ACC_RDWR = _medfield.MED_ACC_RDWR
MED_ACC_RDEXT = _medfield.MED_ACC_RDEXT
MED_ACC_CREAT = _medfield.MED_ACC_CREAT
MED_ACC_UNDEF = _medfield.MED_ACC_UNDEF
MED_UNSTRUCTURED_MESH = _medfield.MED_UNSTRUCTURED_MESH
MED_STRUCTURED_MESH = _medfield.MED_STRUCTURED_MESH
MED_UNDEF_MESH_TYPE = _medfield.MED_UNDEF_MESH_TYPE
MED_CARTESIAN_GRID = _medfield.MED_CARTESIAN_GRID
MED_POLAR_GRID = _medfield.MED_POLAR_GRID
MED_CURVILINEAR_GRID = _medfield.MED_CURVILINEAR_GRID
MED_UNDEF_GRID_TYPE = _medfield.MED_UNDEF_GRID_TYPE
MED_CELL = _medfield.MED_CELL
MED_DESCENDING_FACE = _medfield.MED_DESCENDING_FACE
MED_DESCENDING_EDGE = _medfield.MED_DESCENDING_EDGE
MED_NODE = _medfield.MED_NODE
MED_NODE_ELEMENT = _medfield.MED_NODE_ELEMENT
MED_STRUCT_ELEMENT = _medfield.MED_STRUCT_ELEMENT
MED_ALL_ENTITY_TYPE = _medfield.MED_ALL_ENTITY_TYPE
MED_UNDEF_ENTITY_TYPE = _medfield.MED_UNDEF_ENTITY_TYPE
MED_N_ENTITY_TYPES = _medfield.MED_N_ENTITY_TYPES
MED_COORDINATE = _medfield.MED_COORDINATE
MED_CONNECTIVITY = _medfield.MED_CONNECTIVITY
MED_NAME = _medfield.MED_NAME
MED_NUMBER = _medfield.MED_NUMBER
MED_FAMILY_NUMBER = _medfield.MED_FAMILY_NUMBER
MED_COORDINATE_AXIS1 = _medfield.MED_COORDINATE_AXIS1
MED_COORDINATE_AXIS2 = _medfield.MED_COORDINATE_AXIS2
MED_COORDINATE_AXIS3 = _medfield.MED_COORDINATE_AXIS3
MED_INDEX_FACE = _medfield.MED_INDEX_FACE
MED_INDEX_NODE = _medfield.MED_INDEX_NODE
MED_GLOBAL_NUMBER = _medfield.MED_GLOBAL_NUMBER
MED_VARIABLE_ATTRIBUTE = _medfield.MED_VARIABLE_ATTRIBUTE
MED_COORDINATE_TRSF = _medfield.MED_COORDINATE_TRSF
MED_UNDEF_DATATYPE = _medfield.MED_UNDEF_DATATYPE
MED_INTERNAL_FLOAT32 = _medfield.MED_INTERNAL_FLOAT32
MED_INTERNAL_FLOAT64 = _medfield.MED_INTERNAL_FLOAT64
MED_INTERNAL_INT32 = _medfield.MED_INTERNAL_INT32
MED_INTERNAL_INT64 = _medfield.MED_INTERNAL_INT64
MED_INTERNAL_INT = _medfield.MED_INTERNAL_INT
MED_INTERNAL_NAME = _medfield.MED_INTERNAL_NAME
MED_INTERNAL_SNAME = _medfield.MED_INTERNAL_SNAME
MED_INTERNAL_LNAME = _medfield.MED_INTERNAL_LNAME
MED_INTERNAL_IDENT = _medfield.MED_INTERNAL_IDENT
MED_INTERNAL_CHAR = _medfield.MED_INTERNAL_CHAR
MED_INTERNAL_UNDEF = _medfield.MED_INTERNAL_UNDEF
MED_DOUBLE = _medfield.MED_DOUBLE
MED_FLOAT64 = _medfield.MED_FLOAT64
MED_FLOAT32 = _medfield.MED_FLOAT32
MED_INT32 = _medfield.MED_INT32
MED_INT64 = _medfield.MED_INT64
MED_INT = _medfield.MED_INT
MED_ATT_FLOAT64 = _medfield.MED_ATT_FLOAT64
MED_ATT_INT = _medfield.MED_ATT_INT
MED_ATT_NAME = _medfield.MED_ATT_NAME
MED_ATT_UNDEF = _medfield.MED_ATT_UNDEF
MED_MESH = _medfield.MED_MESH
MED_FIELD = _medfield.MED_FIELD
MED_LIBRARY = _medfield.MED_LIBRARY
MED_FILE = _medfield.MED_FILE
MED_MESH_SUPPORT = _medfield.MED_MESH_SUPPORT
MED_ELSTRUCT = _medfield.MED_ELSTRUCT
MED_FAMILY = _medfield.MED_FAMILY
MED_EQUIVALENCE = _medfield.MED_EQUIVALENCE
MED_GROUP = _medfield.MED_GROUP
MED_JOINT = _medfield.MED_JOINT
MED_LOCALIZATION = _medfield.MED_LOCALIZATION
MED_PROFILE = _medfield.MED_PROFILE
MED_FILTER = _medfield.MED_FILTER
MED_INTERPOLATION = _medfield.MED_INTERPOLATION
MED_NUMERICAL_DATA = _medfield.MED_NUMERICAL_DATA
MED_LINK = _medfield.MED_LINK
MED_CLASS_UNDEF = _medfield.MED_CLASS_UNDEF
MED_CLASS_ALL = _medfield.MED_CLASS_ALL
MED_POINT1 = _medfield.MED_POINT1
MED_SEG2 = _medfield.MED_SEG2
MED_SEG3 = _medfield.MED_SEG3
MED_SEG4 = _medfield.MED_SEG4
MED_TRIA3 = _medfield.MED_TRIA3
MED_QUAD4 = _medfield.MED_QUAD4
MED_TRIA6 = _medfield.MED_TRIA6
MED_TRIA7 = _medfield.MED_TRIA7
MED_QUAD8 = _medfield.MED_QUAD8
MED_QUAD9 = _medfield.MED_QUAD9
MED_TETRA4 = _medfield.MED_TETRA4
MED_PYRA5 = _medfield.MED_PYRA5
MED_PENTA6 = _medfield.MED_PENTA6
MED_HEXA8 = _medfield.MED_HEXA8
MED_TETRA10 = _medfield.MED_TETRA10
MED_OCTA12 = _medfield.MED_OCTA12
MED_PYRA13 = _medfield.MED_PYRA13
MED_PENTA15 = _medfield.MED_PENTA15
MED_PENTA18 = _medfield.MED_PENTA18
MED_HEXA20 = _medfield.MED_HEXA20
MED_HEXA27 = _medfield.MED_HEXA27
MED_POLYGON = _medfield.MED_POLYGON
MED_POLYGON2 = _medfield.MED_POLYGON2
MED_POLYHEDRON = _medfield.MED_POLYHEDRON
MED_STRUCT_GEO_INTERNAL = _medfield.MED_STRUCT_GEO_INTERNAL
MED_STRUCT_GEO_SUP_INTERNAL = _medfield.MED_STRUCT_GEO_SUP_INTERNAL
MED_NONE = _medfield.MED_NONE
MED_NO_GEOTYPE = _medfield.MED_NO_GEOTYPE
MED_UNDEF_GEOTYPE = _medfield.MED_UNDEF_GEOTYPE
MED_UNDEF_GEOMETRY_TYPE = _medfield.MED_UNDEF_GEOMETRY_TYPE
MED_ALL_GEOTYPE = _medfield.MED_ALL_GEOTYPE
MED_GEO_ALL = _medfield.MED_GEO_ALL
MED_N_CELL_GEO = _medfield.MED_N_CELL_GEO
MED_N_CELL_FIXED_GEO = _medfield.MED_N_CELL_FIXED_GEO
MED_N_CELL_GEO_FIXED_CON = _medfield.MED_N_CELL_GEO_FIXED_CON
MED_N_FACE_GEO = _medfield.MED_N_FACE_GEO
MED_N_FACE_FIXED_GEO = _medfield.MED_N_FACE_FIXED_GEO
MED_N_FACE_GEO_FIXED_CON = _medfield.MED_N_FACE_GEO_FIXED_CON
MED_N_EDGE_TYPES = _medfield.MED_N_EDGE_TYPES
MED_N_EDGE_FIXED_GEO = _medfield.MED_N_EDGE_FIXED_GEO
MED_N_EDGE_GEO_FIXED_CON = _medfield.MED_N_EDGE_GEO_FIXED_CON
MED_N_NODE_GEO = _medfield.MED_N_NODE_GEO
MED_N_NODE_FIXED_GEO = _medfield.MED_N_NODE_FIXED_GEO
MED_N_NODE_GEO_FIXED_CON = _medfield.MED_N_NODE_GEO_FIXED_CON
MED_NODAL = _medfield.MED_NODAL
MED_DESCENDING = _medfield.MED_DESCENDING
MED_UNDEF_CONNECTIVITY_MODE = _medfield.MED_UNDEF_CONNECTIVITY_MODE
MED_NO_CMODE = _medfield.MED_NO_CMODE
MED_CARTESIAN = _medfield.MED_CARTESIAN
MED_CYLINDRICAL = _medfield.MED_CYLINDRICAL
MED_SPHERICAL = _medfield.MED_SPHERICAL
MED_UNDEF_AXIS_TYPE = _medfield.MED_UNDEF_AXIS_TYPE
MED_FALSE = _medfield.MED_FALSE
MED_TRUE = _medfield.MED_TRUE
MED_GAUSS_ELNO = _medfield.MED_GAUSS_ELNO
MED_IPOINT_ELNO = _medfield.MED_IPOINT_ELNO
MED_NO_NAME = _medfield.MED_NO_NAME
MED_NO_MESHNAME = _medfield.MED_NO_MESHNAME
MED_NO_MESH = _medfield.MED_NO_MESH
MED_NO_MESH_SUPPORT = _medfield.MED_NO_MESH_SUPPORT
MED_NO_LOCALIZATION = _medfield.MED_NO_LOCALIZATION
MED_NO_INTERPOLATION = _medfield.MED_NO_INTERPOLATION
MED_NO_IPOINT_INTERNAL = _medfield.MED_NO_IPOINT_INTERNAL
MED_NO_PROFILE = _medfield.MED_NO_PROFILE
MED_NO_GROUP = _medfield.MED_NO_GROUP
MED_ALLENTITIES_PROFILE = _medfield.MED_ALLENTITIES_PROFILE
MED_NO_PROFILE_INTERNAL = _medfield.MED_NO_PROFILE_INTERNAL
MED_SAME_PROFILE_INTERNAL = _medfield.MED_SAME_PROFILE_INTERNAL
MED_ALL_CONSTITUENT = _medfield.MED_ALL_CONSTITUENT
MED_UNDEF_SIZE = _medfield.MED_UNDEF_SIZE
MED_NO_PROFILE_SIZE = _medfield.MED_NO_PROFILE_SIZE
MED_SORT_DTIT = _medfield.MED_SORT_DTIT
MED_SORT_ITDT = _medfield.MED_SORT_ITDT
MED_SORT_UNDEF = _medfield.MED_SORT_UNDEF
MED_NO_DT = _medfield.MED_NO_DT
MED_NO_IT = _medfield.MED_NO_IT
MED_UNDEF_DT = _medfield.MED_UNDEF_DT
MED_ATT_NOT_FILLED = _medfield.MED_ATT_NOT_FILLED
MED_MAX_FILTER_SPACES = _medfield.MED_MAX_FILTER_SPACES
class med_filter(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, med_filter, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, med_filter, name)
    __repr__ = _swig_repr
    __swig_setmethods__["nspaces"] = _medfield.med_filter_nspaces_set
    __swig_getmethods__["nspaces"] = _medfield.med_filter_nspaces_get
    if _newclass:
        nspaces = _swig_property(_medfield.med_filter_nspaces_get, _medfield.med_filter_nspaces_set)
    __swig_setmethods__["memspace"] = _medfield.med_filter_memspace_set
    __swig_getmethods__["memspace"] = _medfield.med_filter_memspace_get
    if _newclass:
        memspace = _swig_property(_medfield.med_filter_memspace_get, _medfield.med_filter_memspace_set)
    __swig_setmethods__["diskspace"] = _medfield.med_filter_diskspace_set
    __swig_getmethods__["diskspace"] = _medfield.med_filter_diskspace_get
    if _newclass:
        diskspace = _swig_property(_medfield.med_filter_diskspace_get, _medfield.med_filter_diskspace_set)
    __swig_setmethods__["nentity"] = _medfield.med_filter_nentity_set
    __swig_getmethods__["nentity"] = _medfield.med_filter_nentity_get
    if _newclass:
        nentity = _swig_property(_medfield.med_filter_nentity_get, _medfield.med_filter_nentity_set)
    __swig_setmethods__["nvaluesperentity"] = _medfield.med_filter_nvaluesperentity_set
    __swig_getmethods__["nvaluesperentity"] = _medfield.med_filter_nvaluesperentity_get
    if _newclass:
        nvaluesperentity = _swig_property(_medfield.med_filter_nvaluesperentity_get, _medfield.med_filter_nvaluesperentity_set)
    __swig_setmethods__["nconstituentpervalue"] = _medfield.med_filter_nconstituentpervalue_set
    __swig_getmethods__["nconstituentpervalue"] = _medfield.med_filter_nconstituentpervalue_get
    if _newclass:
        nconstituentpervalue = _swig_property(_medfield.med_filter_nconstituentpervalue_get, _medfield.med_filter_nconstituentpervalue_set)
    __swig_setmethods__["constituentselect"] = _medfield.med_filter_constituentselect_set
    __swig_getmethods__["constituentselect"] = _medfield.med_filter_constituentselect_get
    if _newclass:
        constituentselect = _swig_property(_medfield.med_filter_constituentselect_get, _medfield.med_filter_constituentselect_set)
    __swig_setmethods__["switchmode"] = _medfield.med_filter_switchmode_set
    __swig_getmethods__["switchmode"] = _medfield.med_filter_switchmode_get
    if _newclass:
        switchmode = _swig_property(_medfield.med_filter_switchmode_get, _medfield.med_filter_switchmode_set)
    __swig_setmethods__["filterarraysize"] = _medfield.med_filter_filterarraysize_set
    __swig_getmethods__["filterarraysize"] = _medfield.med_filter_filterarraysize_get
    if _newclass:
        filterarraysize = _swig_property(_medfield.med_filter_filterarraysize_get, _medfield.med_filter_filterarraysize_set)
    __swig_setmethods__["filterarray23v30"] = _medfield.med_filter_filterarray23v30_set
    __swig_getmethods__["filterarray23v30"] = _medfield.med_filter_filterarray23v30_get
    if _newclass:
        filterarray23v30 = _swig_property(_medfield.med_filter_filterarray23v30_get, _medfield.med_filter_filterarray23v30_set)
    __swig_setmethods__["profilearraysize"] = _medfield.med_filter_profilearraysize_set
    __swig_getmethods__["profilearraysize"] = _medfield.med_filter_profilearraysize_get
    if _newclass:
        profilearraysize = _swig_property(_medfield.med_filter_profilearraysize_get, _medfield.med_filter_profilearraysize_set)
    __swig_setmethods__["storagemode"] = _medfield.med_filter_storagemode_set
    __swig_getmethods__["storagemode"] = _medfield.med_filter_storagemode_get
    if _newclass:
        storagemode = _swig_property(_medfield.med_filter_storagemode_get, _medfield.med_filter_storagemode_set)
    __swig_setmethods__["profilename"] = _medfield.med_filter_profilename_set
    __swig_getmethods__["profilename"] = _medfield.med_filter_profilename_get
    if _newclass:
        profilename = _swig_property(_medfield.med_filter_profilename_get, _medfield.med_filter_profilename_set)

    def __init__(self):
        """__init__(self) -> med_filter"""
        this = _medfield.new_med_filter()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _medfield.delete_med_filter
    __del__ = lambda self: None
med_filter_swigregister = _medfield.med_filter_swigregister
med_filter_swigregister(med_filter)

MED_NO_FILTER_SIZE = _medfield.MED_NO_FILTER_SIZE
MED_NO_PROFILE_F = _medfield.MED_NO_PROFILE_F
class med_file_version(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, med_file_version, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, med_file_version, name)
    __repr__ = _swig_repr
    __swig_setmethods__["majeur"] = _medfield.med_file_version_majeur_set
    __swig_getmethods__["majeur"] = _medfield.med_file_version_majeur_get
    if _newclass:
        majeur = _swig_property(_medfield.med_file_version_majeur_get, _medfield.med_file_version_majeur_set)
    __swig_setmethods__["mineur"] = _medfield.med_file_version_mineur_set
    __swig_getmethods__["mineur"] = _medfield.med_file_version_mineur_get
    if _newclass:
        mineur = _swig_property(_medfield.med_file_version_mineur_get, _medfield.med_file_version_mineur_set)
    __swig_setmethods__["release"] = _medfield.med_file_version_release_set
    __swig_getmethods__["release"] = _medfield.med_file_version_release_get
    if _newclass:
        release = _swig_property(_medfield.med_file_version_release_get, _medfield.med_file_version_release_set)

    def __init__(self):
        """__init__(self) -> med_file_version"""
        this = _medfield.new_med_file_version()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _medfield.delete_med_file_version
    __del__ = lambda self: None
med_file_version_swigregister = _medfield.med_file_version_swigregister
med_file_version_swigregister(med_file_version)

class med_memfile(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, med_memfile, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, med_memfile, name)
    __repr__ = _swig_repr
    __swig_setmethods__["app_image_ptr"] = _medfield.med_memfile_app_image_ptr_set
    __swig_getmethods__["app_image_ptr"] = _medfield.med_memfile_app_image_ptr_get
    if _newclass:
        app_image_ptr = _swig_property(_medfield.med_memfile_app_image_ptr_get, _medfield.med_memfile_app_image_ptr_set)
    __swig_setmethods__["app_image_size"] = _medfield.med_memfile_app_image_size_set
    __swig_getmethods__["app_image_size"] = _medfield.med_memfile_app_image_size_get
    if _newclass:
        app_image_size = _swig_property(_medfield.med_memfile_app_image_size_get, _medfield.med_memfile_app_image_size_set)
    __swig_setmethods__["ref_count"] = _medfield.med_memfile_ref_count_set
    __swig_getmethods__["ref_count"] = _medfield.med_memfile_ref_count_get
    if _newclass:
        ref_count = _swig_property(_medfield.med_memfile_ref_count_get, _medfield.med_memfile_ref_count_set)
    __swig_setmethods__["fapl_image_ptr"] = _medfield.med_memfile_fapl_image_ptr_set
    __swig_getmethods__["fapl_image_ptr"] = _medfield.med_memfile_fapl_image_ptr_get
    if _newclass:
        fapl_image_ptr = _swig_property(_medfield.med_memfile_fapl_image_ptr_get, _medfield.med_memfile_fapl_image_ptr_set)
    __swig_setmethods__["fapl_image_size"] = _medfield.med_memfile_fapl_image_size_set
    __swig_getmethods__["fapl_image_size"] = _medfield.med_memfile_fapl_image_size_get
    if _newclass:
        fapl_image_size = _swig_property(_medfield.med_memfile_fapl_image_size_get, _medfield.med_memfile_fapl_image_size_set)
    __swig_setmethods__["fapl_ref_count"] = _medfield.med_memfile_fapl_ref_count_set
    __swig_getmethods__["fapl_ref_count"] = _medfield.med_memfile_fapl_ref_count_get
    if _newclass:
        fapl_ref_count = _swig_property(_medfield.med_memfile_fapl_ref_count_get, _medfield.med_memfile_fapl_ref_count_set)
    __swig_setmethods__["vfd_image_ptr"] = _medfield.med_memfile_vfd_image_ptr_set
    __swig_getmethods__["vfd_image_ptr"] = _medfield.med_memfile_vfd_image_ptr_get
    if _newclass:
        vfd_image_ptr = _swig_property(_medfield.med_memfile_vfd_image_ptr_get, _medfield.med_memfile_vfd_image_ptr_set)
    __swig_setmethods__["vfd_image_size"] = _medfield.med_memfile_vfd_image_size_set
    __swig_getmethods__["vfd_image_size"] = _medfield.med_memfile_vfd_image_size_get
    if _newclass:
        vfd_image_size = _swig_property(_medfield.med_memfile_vfd_image_size_get, _medfield.med_memfile_vfd_image_size_set)
    __swig_setmethods__["vfd_ref_count"] = _medfield.med_memfile_vfd_ref_count_set
    __swig_getmethods__["vfd_ref_count"] = _medfield.med_memfile_vfd_ref_count_get
    if _newclass:
        vfd_ref_count = _swig_property(_medfield.med_memfile_vfd_ref_count_get, _medfield.med_memfile_vfd_ref_count_set)
    __swig_setmethods__["flags"] = _medfield.med_memfile_flags_set
    __swig_getmethods__["flags"] = _medfield.med_memfile_flags_get
    if _newclass:
        flags = _swig_property(_medfield.med_memfile_flags_get, _medfield.med_memfile_flags_set)

    def __init__(self):
        """__init__(self) -> med_memfile"""
        this = _medfield.new_med_memfile()
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this
    __swig_destroy__ = _medfield.delete_med_memfile
    __del__ = lambda self: None
med_memfile_swigregister = _medfield.med_memfile_swigregister
med_memfile_swigregister(med_memfile)

MED_PARTICLE_NAME = _medfield.MED_PARTICLE_NAME
MED_BALL_NAME = _medfield.MED_BALL_NAME
MED_BEAM_NAME = _medfield.MED_BEAM_NAME
MED_PARTICLE_LABEL = _medfield.MED_PARTICLE_LABEL
MED_BALL_DIAMETER = _medfield.MED_BALL_DIAMETER
MED_BEAM_THICKNESS = _medfield.MED_BEAM_THICKNESS
import med.medenum
class MEDBOOL(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDBOOL, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDBOOL, name)
    __repr__ = _swig_repr

    def iterator(self) -> "swig::SwigPyIterator_medfield_module *":
        return _medfield.MEDBOOL_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self) -> "bool":
        return _medfield.MEDBOOL___nonzero__(self)

    def __bool__(self) -> "bool":
        return _medfield.MEDBOOL___bool__(self)

    def __len__(self) -> "std::vector< bool >::size_type":
        return _medfield.MEDBOOL___len__(self)

    def __getslice__(self, i: 'std::vector< bool >::difference_type', j: 'std::vector< bool >::difference_type') -> "std::vector< bool,std::allocator< bool > > *":
        return _medfield.MEDBOOL___getslice__(self, i, j)

    def __setslice__(self, *args) -> "void":
        return _medfield.MEDBOOL___setslice__(self, *args)

    def __delslice__(self, i: 'std::vector< bool >::difference_type', j: 'std::vector< bool >::difference_type') -> "void":
        return _medfield.MEDBOOL___delslice__(self, i, j)

    def __delitem__(self, *args) -> "void":
        return _medfield.MEDBOOL___delitem__(self, *args)

    def __getitem__(self, *args) -> "std::vector< bool >::value_type":
        return _medfield.MEDBOOL___getitem__(self, *args)

    def __setitem__(self, *args) -> "void":
        return _medfield.MEDBOOL___setitem__(self, *args)

    def pop(self) -> "std::vector< bool >::value_type":
        return _medfield.MEDBOOL_pop(self)

    def append(self, x: 'std::vector< bool >::value_type') -> "void":
        return _medfield.MEDBOOL_append(self, x)

    def empty(self) -> "bool":
        return _medfield.MEDBOOL_empty(self)

    def size(self) -> "std::vector< bool >::size_type":
        return _medfield.MEDBOOL_size(self)

    def swap(self, v: 'MEDBOOL') -> "void":
        return _medfield.MEDBOOL_swap(self, v)

    def begin(self) -> "std::vector< bool >::iterator":
        return _medfield.MEDBOOL_begin(self)

    def end(self) -> "std::vector< bool >::iterator":
        return _medfield.MEDBOOL_end(self)

    def rbegin(self) -> "std::vector< bool >::reverse_iterator":
        return _medfield.MEDBOOL_rbegin(self)

    def rend(self) -> "std::vector< bool >::reverse_iterator":
        return _medfield.MEDBOOL_rend(self)

    def clear(self) -> "void":
        return _medfield.MEDBOOL_clear(self)

    def get_allocator(self) -> "std::vector< bool >::allocator_type":
        return _medfield.MEDBOOL_get_allocator(self)

    def pop_back(self) -> "void":
        return _medfield.MEDBOOL_pop_back(self)

    def erase(self, *args) -> "std::vector< bool >::iterator":
        return _medfield.MEDBOOL_erase(self, *args)

    def __init__(self, *args):
        this = _medfield.new_MEDBOOL(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x: 'std::vector< bool >::value_type') -> "void":
        return _medfield.MEDBOOL_push_back(self, x)

    def front(self) -> "std::vector< bool >::value_type":
        return _medfield.MEDBOOL_front(self)

    def back(self) -> "std::vector< bool >::value_type":
        return _medfield.MEDBOOL_back(self)

    def assign(self, n: 'std::vector< bool >::size_type', x: 'std::vector< bool >::value_type') -> "void":
        return _medfield.MEDBOOL_assign(self, n, x)

    def resize(self, *args) -> "void":
        return _medfield.MEDBOOL_resize(self, *args)

    def insert(self, *args) -> "void":
        return _medfield.MEDBOOL_insert(self, *args)

    def reserve(self, n: 'std::vector< bool >::size_type') -> "void":
        return _medfield.MEDBOOL_reserve(self, n)

    def capacity(self) -> "std::vector< bool >::size_type":
        return _medfield.MEDBOOL_capacity(self)
    __swig_destroy__ = _medfield.delete_MEDBOOL
    __del__ = lambda self: None
MEDBOOL_swigregister = _medfield.MEDBOOL_swigregister
MEDBOOL_swigregister(MEDBOOL)
cvar = _medfield.cvar
MED_GET_ENTITY_TYPENAME = cvar.MED_GET_ENTITY_TYPENAME
MED_GET_CELL_GEOMETRY_TYPENAME = cvar.MED_GET_CELL_GEOMETRY_TYPENAME
MED_GET_FACE_GEOMETRY_TYPENAME = cvar.MED_GET_FACE_GEOMETRY_TYPENAME


MEDBOOL.__str__= lambda self: str([x for x in self])
MEDBOOL.__repr__= lambda self: "MEDBOOL("+str([x for x in self])+")"

class MEDFLOAT(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDFLOAT, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDFLOAT, name)
    __repr__ = _swig_repr

    def iterator(self) -> "swig::SwigPyIterator_medfield_module *":
        return _medfield.MEDFLOAT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self) -> "bool":
        return _medfield.MEDFLOAT___nonzero__(self)

    def __bool__(self) -> "bool":
        return _medfield.MEDFLOAT___bool__(self)

    def __len__(self) -> "std::vector< double >::size_type":
        return _medfield.MEDFLOAT___len__(self)

    def __getslice__(self, i: 'std::vector< double >::difference_type', j: 'std::vector< double >::difference_type') -> "std::vector< double,std::allocator< double > > *":
        return _medfield.MEDFLOAT___getslice__(self, i, j)

    def __setslice__(self, *args) -> "void":
        return _medfield.MEDFLOAT___setslice__(self, *args)

    def __delslice__(self, i: 'std::vector< double >::difference_type', j: 'std::vector< double >::difference_type') -> "void":
        return _medfield.MEDFLOAT___delslice__(self, i, j)

    def __delitem__(self, *args) -> "void":
        return _medfield.MEDFLOAT___delitem__(self, *args)

    def __getitem__(self, *args) -> "std::vector< double >::value_type const &":
        return _medfield.MEDFLOAT___getitem__(self, *args)

    def __setitem__(self, *args) -> "void":
        return _medfield.MEDFLOAT___setitem__(self, *args)

    def pop(self) -> "std::vector< double >::value_type":
        return _medfield.MEDFLOAT_pop(self)

    def append(self, x: 'std::vector< double >::value_type const &') -> "void":
        return _medfield.MEDFLOAT_append(self, x)

    def empty(self) -> "bool":
        return _medfield.MEDFLOAT_empty(self)

    def size(self) -> "std::vector< double >::size_type":
        return _medfield.MEDFLOAT_size(self)

    def swap(self, v: 'MEDFLOAT') -> "void":
        return _medfield.MEDFLOAT_swap(self, v)

    def begin(self) -> "std::vector< double >::iterator":
        return _medfield.MEDFLOAT_begin(self)

    def end(self) -> "std::vector< double >::iterator":
        return _medfield.MEDFLOAT_end(self)

    def rbegin(self) -> "std::vector< double >::reverse_iterator":
        return _medfield.MEDFLOAT_rbegin(self)

    def rend(self) -> "std::vector< double >::reverse_iterator":
        return _medfield.MEDFLOAT_rend(self)

    def clear(self) -> "void":
        return _medfield.MEDFLOAT_clear(self)

    def get_allocator(self) -> "std::vector< double >::allocator_type":
        return _medfield.MEDFLOAT_get_allocator(self)

    def pop_back(self) -> "void":
        return _medfield.MEDFLOAT_pop_back(self)

    def erase(self, *args) -> "std::vector< double >::iterator":
        return _medfield.MEDFLOAT_erase(self, *args)

    def __init__(self, *args):
        this = _medfield.new_MEDFLOAT(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x: 'std::vector< double >::value_type const &') -> "void":
        return _medfield.MEDFLOAT_push_back(self, x)

    def front(self) -> "std::vector< double >::value_type const &":
        return _medfield.MEDFLOAT_front(self)

    def back(self) -> "std::vector< double >::value_type const &":
        return _medfield.MEDFLOAT_back(self)

    def assign(self, n: 'std::vector< double >::size_type', x: 'std::vector< double >::value_type const &') -> "void":
        return _medfield.MEDFLOAT_assign(self, n, x)

    def resize(self, *args) -> "void":
        return _medfield.MEDFLOAT_resize(self, *args)

    def insert(self, *args) -> "void":
        return _medfield.MEDFLOAT_insert(self, *args)

    def reserve(self, n: 'std::vector< double >::size_type') -> "void":
        return _medfield.MEDFLOAT_reserve(self, n)

    def capacity(self) -> "std::vector< double >::size_type":
        return _medfield.MEDFLOAT_capacity(self)

    def __iadd__(self, value: 'MEDFLOAT') -> "std::vector< med_float,std::allocator< med_float > > &":
        return _medfield.MEDFLOAT___iadd__(self, value)

    def __add__(self, value: 'MEDFLOAT') -> "std::vector< med_float,std::allocator< med_float > >":
        return _medfield.MEDFLOAT___add__(self, value)

    def __isub__(self, value: 'MEDFLOAT') -> "std::vector< med_float,std::allocator< med_float > > &":
        return _medfield.MEDFLOAT___isub__(self, value)

    def __sub__(self, value: 'MEDFLOAT') -> "std::vector< med_float,std::allocator< med_float > >":
        return _medfield.MEDFLOAT___sub__(self, value)

    def __imul__(self, value: 'MEDFLOAT') -> "std::vector< med_float,std::allocator< med_float > > &":
        return _medfield.MEDFLOAT___imul__(self, value)

    def __mul__(self, value: 'MEDFLOAT') -> "std::vector< med_float,std::allocator< med_float > >":
        return _medfield.MEDFLOAT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medfield.MEDFLOAT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medfield.MEDFLOAT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value: 'MEDFLOAT') -> "bool":
        return _medfield.MEDFLOAT___le__(self, value)

    def __lt__(self, value: 'MEDFLOAT') -> "bool":
        return _medfield.MEDFLOAT___lt__(self, value)

    def __gt__(self, value: 'MEDFLOAT') -> "bool":
        return _medfield.MEDFLOAT___gt__(self, value)

    def __ge__(self, value: 'MEDFLOAT') -> "bool":
        return _medfield.MEDFLOAT___ge__(self, value)

    def __eq__(self, value: 'MEDFLOAT') -> "bool":
        return _medfield.MEDFLOAT___eq__(self, value)

    def __ne__(self, value: 'MEDFLOAT') -> "bool":
        return _medfield.MEDFLOAT___ne__(self, value)
    __swig_destroy__ = _medfield.delete_MEDFLOAT
    __del__ = lambda self: None
MEDFLOAT_swigregister = _medfield.MEDFLOAT_swigregister
MEDFLOAT_swigregister(MEDFLOAT)


MEDFLOAT.__str__= lambda self: str([x for x in self])
MEDFLOAT.__repr__= lambda self:"MEDFLOAT" +"("+str([x for x in self])+")"


MEDFLOAT64=MEDFLOAT
MEDDOUBLE=MEDFLOAT

class MEDFLOAT32(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDFLOAT32, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDFLOAT32, name)
    __repr__ = _swig_repr

    def iterator(self) -> "swig::SwigPyIterator_medfield_module *":
        return _medfield.MEDFLOAT32_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self) -> "bool":
        return _medfield.MEDFLOAT32___nonzero__(self)

    def __bool__(self) -> "bool":
        return _medfield.MEDFLOAT32___bool__(self)

    def __len__(self) -> "std::vector< float >::size_type":
        return _medfield.MEDFLOAT32___len__(self)

    def __getslice__(self, i: 'std::vector< float >::difference_type', j: 'std::vector< float >::difference_type') -> "std::vector< float,std::allocator< float > > *":
        return _medfield.MEDFLOAT32___getslice__(self, i, j)

    def __setslice__(self, *args) -> "void":
        return _medfield.MEDFLOAT32___setslice__(self, *args)

    def __delslice__(self, i: 'std::vector< float >::difference_type', j: 'std::vector< float >::difference_type') -> "void":
        return _medfield.MEDFLOAT32___delslice__(self, i, j)

    def __delitem__(self, *args) -> "void":
        return _medfield.MEDFLOAT32___delitem__(self, *args)

    def __getitem__(self, *args) -> "std::vector< float >::value_type const &":
        return _medfield.MEDFLOAT32___getitem__(self, *args)

    def __setitem__(self, *args) -> "void":
        return _medfield.MEDFLOAT32___setitem__(self, *args)

    def pop(self) -> "std::vector< float >::value_type":
        return _medfield.MEDFLOAT32_pop(self)

    def append(self, x: 'std::vector< float >::value_type const &') -> "void":
        return _medfield.MEDFLOAT32_append(self, x)

    def empty(self) -> "bool":
        return _medfield.MEDFLOAT32_empty(self)

    def size(self) -> "std::vector< float >::size_type":
        return _medfield.MEDFLOAT32_size(self)

    def swap(self, v: 'MEDFLOAT32') -> "void":
        return _medfield.MEDFLOAT32_swap(self, v)

    def begin(self) -> "std::vector< float >::iterator":
        return _medfield.MEDFLOAT32_begin(self)

    def end(self) -> "std::vector< float >::iterator":
        return _medfield.MEDFLOAT32_end(self)

    def rbegin(self) -> "std::vector< float >::reverse_iterator":
        return _medfield.MEDFLOAT32_rbegin(self)

    def rend(self) -> "std::vector< float >::reverse_iterator":
        return _medfield.MEDFLOAT32_rend(self)

    def clear(self) -> "void":
        return _medfield.MEDFLOAT32_clear(self)

    def get_allocator(self) -> "std::vector< float >::allocator_type":
        return _medfield.MEDFLOAT32_get_allocator(self)

    def pop_back(self) -> "void":
        return _medfield.MEDFLOAT32_pop_back(self)

    def erase(self, *args) -> "std::vector< float >::iterator":
        return _medfield.MEDFLOAT32_erase(self, *args)

    def __init__(self, *args):
        this = _medfield.new_MEDFLOAT32(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x: 'std::vector< float >::value_type const &') -> "void":
        return _medfield.MEDFLOAT32_push_back(self, x)

    def front(self) -> "std::vector< float >::value_type const &":
        return _medfield.MEDFLOAT32_front(self)

    def back(self) -> "std::vector< float >::value_type const &":
        return _medfield.MEDFLOAT32_back(self)

    def assign(self, n: 'std::vector< float >::size_type', x: 'std::vector< float >::value_type const &') -> "void":
        return _medfield.MEDFLOAT32_assign(self, n, x)

    def resize(self, *args) -> "void":
        return _medfield.MEDFLOAT32_resize(self, *args)

    def insert(self, *args) -> "void":
        return _medfield.MEDFLOAT32_insert(self, *args)

    def reserve(self, n: 'std::vector< float >::size_type') -> "void":
        return _medfield.MEDFLOAT32_reserve(self, n)

    def capacity(self) -> "std::vector< float >::size_type":
        return _medfield.MEDFLOAT32_capacity(self)

    def __iadd__(self, value: 'MEDFLOAT32') -> "std::vector< med_float32,std::allocator< med_float32 > > &":
        return _medfield.MEDFLOAT32___iadd__(self, value)

    def __add__(self, value: 'MEDFLOAT32') -> "std::vector< med_float32,std::allocator< med_float32 > >":
        return _medfield.MEDFLOAT32___add__(self, value)

    def __isub__(self, value: 'MEDFLOAT32') -> "std::vector< med_float32,std::allocator< med_float32 > > &":
        return _medfield.MEDFLOAT32___isub__(self, value)

    def __sub__(self, value: 'MEDFLOAT32') -> "std::vector< med_float32,std::allocator< med_float32 > >":
        return _medfield.MEDFLOAT32___sub__(self, value)

    def __imul__(self, value: 'MEDFLOAT32') -> "std::vector< med_float32,std::allocator< med_float32 > > &":
        return _medfield.MEDFLOAT32___imul__(self, value)

    def __mul__(self, value: 'MEDFLOAT32') -> "std::vector< med_float32,std::allocator< med_float32 > >":
        return _medfield.MEDFLOAT32___mul__(self, value)

    def __itruediv__(self, *args):
        return _medfield.MEDFLOAT32___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medfield.MEDFLOAT32___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value: 'MEDFLOAT32') -> "bool":
        return _medfield.MEDFLOAT32___le__(self, value)

    def __lt__(self, value: 'MEDFLOAT32') -> "bool":
        return _medfield.MEDFLOAT32___lt__(self, value)

    def __gt__(self, value: 'MEDFLOAT32') -> "bool":
        return _medfield.MEDFLOAT32___gt__(self, value)

    def __ge__(self, value: 'MEDFLOAT32') -> "bool":
        return _medfield.MEDFLOAT32___ge__(self, value)

    def __eq__(self, value: 'MEDFLOAT32') -> "bool":
        return _medfield.MEDFLOAT32___eq__(self, value)

    def __ne__(self, value: 'MEDFLOAT32') -> "bool":
        return _medfield.MEDFLOAT32___ne__(self, value)
    __swig_destroy__ = _medfield.delete_MEDFLOAT32
    __del__ = lambda self: None
MEDFLOAT32_swigregister = _medfield.MEDFLOAT32_swigregister
MEDFLOAT32_swigregister(MEDFLOAT32)


MEDFLOAT32.__str__= lambda self: str([x for x in self])
MEDFLOAT32.__repr__= lambda self:"MEDFLOAT32" +"("+str([x for x in self])+")"

class MEDINT(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDINT, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDINT, name)
    __repr__ = _swig_repr

    def iterator(self) -> "swig::SwigPyIterator_medfield_module *":
        return _medfield.MEDINT_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self) -> "bool":
        return _medfield.MEDINT___nonzero__(self)

    def __bool__(self) -> "bool":
        return _medfield.MEDINT___bool__(self)

    def __len__(self) -> "std::vector< int >::size_type":
        return _medfield.MEDINT___len__(self)

    def __getslice__(self, i: 'std::vector< int >::difference_type', j: 'std::vector< int >::difference_type') -> "std::vector< int,std::allocator< int > > *":
        return _medfield.MEDINT___getslice__(self, i, j)

    def __setslice__(self, *args) -> "void":
        return _medfield.MEDINT___setslice__(self, *args)

    def __delslice__(self, i: 'std::vector< int >::difference_type', j: 'std::vector< int >::difference_type') -> "void":
        return _medfield.MEDINT___delslice__(self, i, j)

    def __delitem__(self, *args) -> "void":
        return _medfield.MEDINT___delitem__(self, *args)

    def __getitem__(self, *args) -> "std::vector< int >::value_type const &":
        return _medfield.MEDINT___getitem__(self, *args)

    def __setitem__(self, *args) -> "void":
        return _medfield.MEDINT___setitem__(self, *args)

    def pop(self) -> "std::vector< int >::value_type":
        return _medfield.MEDINT_pop(self)

    def append(self, x: 'std::vector< int >::value_type const &') -> "void":
        return _medfield.MEDINT_append(self, x)

    def empty(self) -> "bool":
        return _medfield.MEDINT_empty(self)

    def size(self) -> "std::vector< int >::size_type":
        return _medfield.MEDINT_size(self)

    def swap(self, v: 'MEDINT') -> "void":
        return _medfield.MEDINT_swap(self, v)

    def begin(self) -> "std::vector< int >::iterator":
        return _medfield.MEDINT_begin(self)

    def end(self) -> "std::vector< int >::iterator":
        return _medfield.MEDINT_end(self)

    def rbegin(self) -> "std::vector< int >::reverse_iterator":
        return _medfield.MEDINT_rbegin(self)

    def rend(self) -> "std::vector< int >::reverse_iterator":
        return _medfield.MEDINT_rend(self)

    def clear(self) -> "void":
        return _medfield.MEDINT_clear(self)

    def get_allocator(self) -> "std::vector< int >::allocator_type":
        return _medfield.MEDINT_get_allocator(self)

    def pop_back(self) -> "void":
        return _medfield.MEDINT_pop_back(self)

    def erase(self, *args) -> "std::vector< int >::iterator":
        return _medfield.MEDINT_erase(self, *args)

    def __init__(self, *args):
        this = _medfield.new_MEDINT(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x: 'std::vector< int >::value_type const &') -> "void":
        return _medfield.MEDINT_push_back(self, x)

    def front(self) -> "std::vector< int >::value_type const &":
        return _medfield.MEDINT_front(self)

    def back(self) -> "std::vector< int >::value_type const &":
        return _medfield.MEDINT_back(self)

    def assign(self, n: 'std::vector< int >::size_type', x: 'std::vector< int >::value_type const &') -> "void":
        return _medfield.MEDINT_assign(self, n, x)

    def resize(self, *args) -> "void":
        return _medfield.MEDINT_resize(self, *args)

    def insert(self, *args) -> "void":
        return _medfield.MEDINT_insert(self, *args)

    def reserve(self, n: 'std::vector< int >::size_type') -> "void":
        return _medfield.MEDINT_reserve(self, n)

    def capacity(self) -> "std::vector< int >::size_type":
        return _medfield.MEDINT_capacity(self)

    def __iadd__(self, value: 'MEDINT') -> "std::vector< med_int,std::allocator< med_int > > &":
        return _medfield.MEDINT___iadd__(self, value)

    def __add__(self, value: 'MEDINT') -> "std::vector< med_int,std::allocator< med_int > >":
        return _medfield.MEDINT___add__(self, value)

    def __isub__(self, value: 'MEDINT') -> "std::vector< med_int,std::allocator< med_int > > &":
        return _medfield.MEDINT___isub__(self, value)

    def __sub__(self, value: 'MEDINT') -> "std::vector< med_int,std::allocator< med_int > >":
        return _medfield.MEDINT___sub__(self, value)

    def __imul__(self, value: 'MEDINT') -> "std::vector< med_int,std::allocator< med_int > > &":
        return _medfield.MEDINT___imul__(self, value)

    def __mul__(self, value: 'MEDINT') -> "std::vector< med_int,std::allocator< med_int > >":
        return _medfield.MEDINT___mul__(self, value)

    def __itruediv__(self, *args):
        return _medfield.MEDINT___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medfield.MEDINT___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value: 'MEDINT') -> "bool":
        return _medfield.MEDINT___le__(self, value)

    def __lt__(self, value: 'MEDINT') -> "bool":
        return _medfield.MEDINT___lt__(self, value)

    def __gt__(self, value: 'MEDINT') -> "bool":
        return _medfield.MEDINT___gt__(self, value)

    def __ge__(self, value: 'MEDINT') -> "bool":
        return _medfield.MEDINT___ge__(self, value)

    def __eq__(self, value: 'MEDINT') -> "bool":
        return _medfield.MEDINT___eq__(self, value)

    def __ne__(self, value: 'MEDINT') -> "bool":
        return _medfield.MEDINT___ne__(self, value)
    __swig_destroy__ = _medfield.delete_MEDINT
    __del__ = lambda self: None
MEDINT_swigregister = _medfield.MEDINT_swigregister
MEDINT_swigregister(MEDINT)


MEDINT.__str__= lambda self: str([x for x in self])
MEDINT.__repr__= lambda self:"MEDINT" +"("+str([x for x in self])+")"


MEDINT32=MEDINT


MEDINT64=None

class MEDCHAR(_object):
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, MEDCHAR, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, MEDCHAR, name)
    __repr__ = _swig_repr

    def iterator(self) -> "swig::SwigPyIterator_medfield_module *":
        return _medfield.MEDCHAR_iterator(self)
    def __iter__(self):
        return self.iterator()

    def __nonzero__(self) -> "bool":
        return _medfield.MEDCHAR___nonzero__(self)

    def __bool__(self) -> "bool":
        return _medfield.MEDCHAR___bool__(self)

    def __len__(self) -> "std::vector< char >::size_type":
        return _medfield.MEDCHAR___len__(self)

    def __getslice__(self, i: 'std::vector< char >::difference_type', j: 'std::vector< char >::difference_type') -> "std::vector< char,std::allocator< char > > *":
        return _medfield.MEDCHAR___getslice__(self, i, j)

    def __setslice__(self, *args) -> "void":
        return _medfield.MEDCHAR___setslice__(self, *args)

    def __delslice__(self, i: 'std::vector< char >::difference_type', j: 'std::vector< char >::difference_type') -> "void":
        return _medfield.MEDCHAR___delslice__(self, i, j)

    def __delitem__(self, *args) -> "void":
        return _medfield.MEDCHAR___delitem__(self, *args)

    def __getitem__(self, *args) -> "std::vector< char >::value_type const &":
        return _medfield.MEDCHAR___getitem__(self, *args)

    def __setitem__(self, *args) -> "void":
        return _medfield.MEDCHAR___setitem__(self, *args)

    def pop(self) -> "std::vector< char >::value_type":
        return _medfield.MEDCHAR_pop(self)

    def append(self, x: 'std::vector< char >::value_type const &') -> "void":
        return _medfield.MEDCHAR_append(self, x)

    def empty(self) -> "bool":
        return _medfield.MEDCHAR_empty(self)

    def size(self) -> "std::vector< char >::size_type":
        return _medfield.MEDCHAR_size(self)

    def swap(self, v: 'MEDCHAR') -> "void":
        return _medfield.MEDCHAR_swap(self, v)

    def begin(self) -> "std::vector< char >::iterator":
        return _medfield.MEDCHAR_begin(self)

    def end(self) -> "std::vector< char >::iterator":
        return _medfield.MEDCHAR_end(self)

    def rbegin(self) -> "std::vector< char >::reverse_iterator":
        return _medfield.MEDCHAR_rbegin(self)

    def rend(self) -> "std::vector< char >::reverse_iterator":
        return _medfield.MEDCHAR_rend(self)

    def clear(self) -> "void":
        return _medfield.MEDCHAR_clear(self)

    def get_allocator(self) -> "std::vector< char >::allocator_type":
        return _medfield.MEDCHAR_get_allocator(self)

    def pop_back(self) -> "void":
        return _medfield.MEDCHAR_pop_back(self)

    def erase(self, *args) -> "std::vector< char >::iterator":
        return _medfield.MEDCHAR_erase(self, *args)

    def __init__(self, *args):
        this = _medfield.new_MEDCHAR(*args)
        try:
            self.this.append(this)
        except __builtin__.Exception:
            self.this = this

    def push_back(self, x: 'std::vector< char >::value_type const &') -> "void":
        return _medfield.MEDCHAR_push_back(self, x)

    def front(self) -> "std::vector< char >::value_type const &":
        return _medfield.MEDCHAR_front(self)

    def back(self) -> "std::vector< char >::value_type const &":
        return _medfield.MEDCHAR_back(self)

    def assign(self, n: 'std::vector< char >::size_type', x: 'std::vector< char >::value_type const &') -> "void":
        return _medfield.MEDCHAR_assign(self, n, x)

    def resize(self, *args) -> "void":
        return _medfield.MEDCHAR_resize(self, *args)

    def insert(self, *args) -> "void":
        return _medfield.MEDCHAR_insert(self, *args)

    def reserve(self, n: 'std::vector< char >::size_type') -> "void":
        return _medfield.MEDCHAR_reserve(self, n)

    def capacity(self) -> "std::vector< char >::size_type":
        return _medfield.MEDCHAR_capacity(self)

    def __iadd__(self, value: 'MEDCHAR') -> "std::vector< char,std::allocator< char > > &":
        return _medfield.MEDCHAR___iadd__(self, value)

    def __add__(self, value: 'MEDCHAR') -> "std::vector< char,std::allocator< char > >":
        return _medfield.MEDCHAR___add__(self, value)

    def __isub__(self, value: 'MEDCHAR') -> "std::vector< char,std::allocator< char > > &":
        return _medfield.MEDCHAR___isub__(self, value)

    def __sub__(self, value: 'MEDCHAR') -> "std::vector< char,std::allocator< char > >":
        return _medfield.MEDCHAR___sub__(self, value)

    def __imul__(self, value: 'MEDCHAR') -> "std::vector< char,std::allocator< char > > &":
        return _medfield.MEDCHAR___imul__(self, value)

    def __mul__(self, value: 'MEDCHAR') -> "std::vector< char,std::allocator< char > >":
        return _medfield.MEDCHAR___mul__(self, value)

    def __itruediv__(self, *args):
        return _medfield.MEDCHAR___itruediv__(self, *args)
    __idiv__ = __itruediv__



    def __truediv__(self, *args):
        return _medfield.MEDCHAR___truediv__(self, *args)
    __div__ = __truediv__



    def __le__(self, value: 'MEDCHAR') -> "bool":
        return _medfield.MEDCHAR___le__(self, value)

    def __lt__(self, value: 'MEDCHAR') -> "bool":
        return _medfield.MEDCHAR___lt__(self, value)

    def __gt__(self, value: 'MEDCHAR') -> "bool":
        return _medfield.MEDCHAR___gt__(self, value)

    def __ge__(self, value: 'MEDCHAR') -> "bool":
        return _medfield.MEDCHAR___ge__(self, value)

    def __eq__(self, value: 'MEDCHAR') -> "bool":
        return _medfield.MEDCHAR___eq__(self, value)

    def __ne__(self, value: 'MEDCHAR') -> "bool":
        return _medfield.MEDCHAR___ne__(self, value)
    __swig_destroy__ = _medfield.delete_MEDCHAR
    __del__ = lambda self: None
MEDCHAR_swigregister = _medfield.MEDCHAR_swigregister
MEDCHAR_swigregister(MEDCHAR)


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


MEDCHAR.__str__= lambda self: str([x for x in self])
MEDCHAR.__repr__= lambda self:"MEDCHAR" +"("+str([x for x in self])+")"


def MEDfieldCr(fid: 'med_idt const', fieldname: 'char const *const', fieldtype: 'med_field_type const', ncomponent: 'med_int const', componentname: 'char const *const', componentunit: 'char const *const', dtunit: 'char const *const', meshname: 'char const *const') -> "char const *const, char const *const, char const *const, char const *const, char const *const":
    """
    MEDfieldCr(fid, fieldname, fieldtype, ncomponent, componentname, componentunit, dtunit, meshname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    fieldtype: enum med_field_type const
    ncomponent: med_int const
    componentname: char const *const
    componentunit: char const *const
    dtunit: char const *const
    meshname: char const *const

    """
    return _medfield.MEDfieldCr(fid, fieldname, fieldtype, ncomponent, componentname, componentunit, dtunit, meshname)

def MEDfieldValueAdvancedWr(fid: 'med_idt const', fieldname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', dt: 'med_float const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', localizationname: 'char const *const', filter: 'med_filter', value: 'unsigned char const *const') -> "char const *const, char const *const, unsigned char const *const":
    """
    MEDfieldValueAdvancedWr(fid, fieldname, numdt, numit, dt, entitype, geotype, localizationname, filter, value) -> med_err

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    localizationname: char const *const
    filter: med_filter const *const
    value: unsigned char const *const

    """
    return _medfield.MEDfieldValueAdvancedWr(fid, fieldname, numdt, numit, dt, entitype, geotype, localizationname, filter, value)

def MEDfieldValueWithProfileWr(fid: 'med_idt const', fieldname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', dt: 'med_float const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', storagemode: 'med_storage_mode const', profilename: 'char const *const', localizationname: 'char const *const', switchmode: 'med_switch_mode const', componentselect: 'med_int const', nentity: 'med_int const', value: 'unsigned char const *const') -> "char const *const, char const *const, char const *const, unsigned char const *const":
    """
    MEDfieldValueWithProfileWr(fid, fieldname, numdt, numit, dt, entitype, geotype, storagemode, profilename, localizationname, switchmode, componentselect, nentity, value) -> med_err

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    storagemode: enum med_storage_mode const
    profilename: char const *const
    localizationname: char const *const
    switchmode: enum med_switch_mode const
    componentselect: med_int const
    nentity: med_int const
    value: unsigned char const *const

    """
    return _medfield.MEDfieldValueWithProfileWr(fid, fieldname, numdt, numit, dt, entitype, geotype, storagemode, profilename, localizationname, switchmode, componentselect, nentity, value)

def MEDfieldValueWr(fid: 'med_idt const', fieldname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', dt: 'med_float const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', switchmode: 'med_switch_mode const', componentselect: 'med_int const', nentity: 'med_int const', value: 'unsigned char const *const') -> "char const *const, unsigned char const *const":
    """
    MEDfieldValueWr(fid, fieldname, numdt, numit, dt, entitype, geotype, switchmode, componentselect, nentity, value) -> med_err

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    numdt: med_int const
    numit: med_int const
    dt: med_float const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    switchmode: enum med_switch_mode const
    componentselect: med_int const
    nentity: med_int const
    value: unsigned char const *const

    """
    return _medfield.MEDfieldValueWr(fid, fieldname, numdt, numit, dt, entitype, geotype, switchmode, componentselect, nentity, value)

def MEDfieldValueAdvancedRd(fid: 'med_idt const', fieldname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', filter: 'med_filter', value: 'unsigned char *const') -> "char const *const, unsigned char *const":
    """
    MEDfieldValueAdvancedRd(fid, fieldname, numdt, numit, entitype, geotype, filter, value) -> med_err

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    filter: med_filter const *const
    value: unsigned char *const

    """
    return _medfield.MEDfieldValueAdvancedRd(fid, fieldname, numdt, numit, entitype, geotype, filter, value)

def MEDfieldValueWithProfileRd(fid: 'med_idt const', fieldname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', storagemode: 'med_storage_mode const', profilename: 'char const *const', switchmode: 'med_switch_mode const', componentselect: 'med_int const', value: 'unsigned char *const') -> "char const *const, char const *const, unsigned char *const":
    """
    MEDfieldValueWithProfileRd(fid, fieldname, numdt, numit, entitype, geotype, storagemode, profilename, switchmode, componentselect, value) -> med_err

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    storagemode: enum med_storage_mode const
    profilename: char const *const
    switchmode: enum med_switch_mode const
    componentselect: med_int const
    value: unsigned char *const

    """
    return _medfield.MEDfieldValueWithProfileRd(fid, fieldname, numdt, numit, entitype, geotype, storagemode, profilename, switchmode, componentselect, value)

def MEDfield23ValueWithProfileRd(fid: 'med_idt const', fieldname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', meshname: 'char const *const', storagemode: 'med_storage_mode const', profilename: 'char const *const', switchmode: 'med_switch_mode const', componentselect: 'med_int const', value: 'unsigned char *const') -> "char const *const, char const *const, char const *const, unsigned char *const":
    """
    MEDfield23ValueWithProfileRd(fid, fieldname, numdt, numit, entitype, geotype, meshname, storagemode, profilename, switchmode, componentselect, value) -> med_err

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    meshname: char const *const
    storagemode: enum med_storage_mode const
    profilename: char const *const
    switchmode: enum med_switch_mode const
    componentselect: med_int const
    value: unsigned char *const

    """
    return _medfield.MEDfield23ValueWithProfileRd(fid, fieldname, numdt, numit, entitype, geotype, meshname, storagemode, profilename, switchmode, componentselect, value)

def MEDfieldValueRd(fid: 'med_idt const', fieldname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', switchmode: 'med_switch_mode const', componentselect: 'med_int const', value: 'unsigned char *const') -> "char const *const, unsigned char *const":
    """
    MEDfieldValueRd(fid, fieldname, numdt, numit, entitype, geotype, switchmode, componentselect, value) -> med_err

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    switchmode: enum med_switch_mode const
    componentselect: med_int const
    value: unsigned char *const

    """
    return _medfield.MEDfieldValueRd(fid, fieldname, numdt, numit, entitype, geotype, switchmode, componentselect, value)

def MEDfieldnComponentByName(fid: 'med_idt const', fieldname: 'char const *const') -> "char const *const":
    """
    MEDfieldnComponentByName(fid, fieldname) -> med_int

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const

    """
    return _medfield.MEDfieldnComponentByName(fid, fieldname)

def MEDfieldnComponent(fid: 'med_idt const', ind: 'int const') -> "med_int":
    """
    MEDfieldnComponent(fid, ind) -> med_int

    Parameters
    ----------
    fid: med_idt const
    ind: int const

    """
    return _medfield.MEDfieldnComponent(fid, ind)

def MEDnField(fid: 'med_idt const') -> "med_int":
    """
    MEDnField(fid) -> med_int

    Parameters
    ----------
    fid: med_idt const

    """
    return _medfield.MEDnField(fid)

def MEDfieldInfo(fid: 'med_idt const', ind: 'int const') -> "char *const, char *const, med_bool *, med_field_type *, char *const, char *const, char *const, med_int *const":
    """
    MEDfieldInfo(fid, ind) -> med_err

    Parameters
    ----------
    fid: med_idt const
    ind: int const

    """
    return _medfield.MEDfieldInfo(fid, ind)

def MEDfieldComputingStepInfo(fid: 'med_idt const', fieldname: 'char const *const', csit: 'int const') -> "char const *const, med_int *const, med_int *const, med_float *const":
    """
    MEDfieldComputingStepInfo(fid, fieldname, csit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    csit: int const

    """
    return _medfield.MEDfieldComputingStepInfo(fid, fieldname, csit)

def MEDfieldComputingStepMeshInfo(fid: 'med_idt const', fieldname: 'char const *const', csit: 'int const') -> "char const *const, med_int *const, med_int *const, med_float *const, med_int *const, med_int *const":
    """
    MEDfieldComputingStepMeshInfo(fid, fieldname, csit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    csit: int const

    """
    return _medfield.MEDfieldComputingStepMeshInfo(fid, fieldname, csit)

def MEDfield23ComputingStepMeshInfo(fid: 'med_idt const', fieldname: 'char const *const', csit: 'int const') -> "char const *const, med_int *const, med_int *const, med_float *const, med_int *const, char *const, med_bool *, med_int *const, med_int *const":
    """
    MEDfield23ComputingStepMeshInfo(fid, fieldname, csit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    csit: int const

    """
    return _medfield.MEDfield23ComputingStepMeshInfo(fid, fieldname, csit)

def MEDfieldComputingStepMeshWr(fid: 'med_idt const', fieldname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', meshnumdt: 'med_int const', meshnumit: 'med_int const') -> "char const *const":
    """
    MEDfieldComputingStepMeshWr(fid, fieldname, numdt, numit, meshnumdt, meshnumit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    numdt: med_int const
    numit: med_int const
    meshnumdt: med_int const
    meshnumit: med_int const

    """
    return _medfield.MEDfieldComputingStepMeshWr(fid, fieldname, numdt, numit, meshnumdt, meshnumit)

def MEDfieldInfoByName(fid: 'med_idt const', fieldname: 'char const *const') -> "char const *const, char *const, med_bool *, med_field_type *, char *const, char *const, char *const, med_int *const":
    """
    MEDfieldInfoByName(fid, fieldname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const

    """
    return _medfield.MEDfieldInfoByName(fid, fieldname)

def MEDfieldnValueWithProfileByName(fid: 'med_idt const', fieldname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', profilename: 'char const *const', storagemode: 'med_storage_mode const') -> "char const *const, char const *const, med_int *const, char *const, med_int *const":
    """
    MEDfieldnValueWithProfileByName(fid, fieldname, numdt, numit, entitype, geotype, profilename, storagemode) -> med_int

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    profilename: char const *const
    storagemode: enum med_storage_mode const

    """
    return _medfield.MEDfieldnValueWithProfileByName(fid, fieldname, numdt, numit, entitype, geotype, profilename, storagemode)

def MEDfieldnValueWithProfile(fid: 'med_idt const', fieldname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', profileit: 'int const', storagemode: 'med_storage_mode const') -> "char const *const, char *const, med_int *const, char *const, med_int *const":
    """
    MEDfieldnValueWithProfile(fid, fieldname, numdt, numit, entitype, geotype, profileit, storagemode) -> med_int

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    profileit: int const
    storagemode: enum med_storage_mode const

    """
    return _medfield.MEDfieldnValueWithProfile(fid, fieldname, numdt, numit, entitype, geotype, profileit, storagemode)

def MEDfieldnValue(fid: 'med_idt const', fieldname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const') -> "char const *const":
    """
    MEDfieldnValue(fid, fieldname, numdt, numit, entitype, geotype) -> med_int

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const

    """
    return _medfield.MEDfieldnValue(fid, fieldname, numdt, numit, entitype, geotype)

def MEDfield23nValueWithProfile(fid: 'med_idt const', fieldname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', meshname: 'char const *const', profileit: 'int const', storagemode: 'med_storage_mode const') -> "char const *const, char const *const, char *const, med_int *const, char *const, med_int *const":
    """
    MEDfield23nValueWithProfile(fid, fieldname, numdt, numit, entitype, geotype, meshname, profileit, storagemode) -> med_int

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    meshname: char const *const
    profileit: int const
    storagemode: enum med_storage_mode const

    """
    return _medfield.MEDfield23nValueWithProfile(fid, fieldname, numdt, numit, entitype, geotype, meshname, profileit, storagemode)

def MEDfieldnProfile(fid: 'med_idt const', fieldname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', enttype: 'med_entity_type const', geotype: 'med_geometry_type const') -> "char const *const, char *const, char *const":
    """
    MEDfieldnProfile(fid, fieldname, numdt, numit, enttype, geotype) -> med_int

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    numdt: med_int const
    numit: med_int const
    enttype: enum med_entity_type const
    geotype: med_geometry_type const

    """
    return _medfield.MEDfieldnProfile(fid, fieldname, numdt, numit, enttype, geotype)

def MEDfield23nProfile(fid: 'med_idt const', fieldname: 'char const *const', numdt: 'med_int const', numit: 'med_int const', entitype: 'med_entity_type const', geotype: 'med_geometry_type const', meshit: 'int const') -> "char const *const, char *const, char *const, char *const":
    """
    MEDfield23nProfile(fid, fieldname, numdt, numit, entitype, geotype, meshit) -> med_int

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    numdt: med_int const
    numit: med_int const
    entitype: enum med_entity_type const
    geotype: med_geometry_type const
    meshit: int const

    """
    return _medfield.MEDfield23nProfile(fid, fieldname, numdt, numit, entitype, geotype, meshit)

def MEDfieldInterpWr(fid: 'med_idt const', fieldname: 'char const *const', interpname: 'char const *const') -> "char const *const, char const *const":
    """
    MEDfieldInterpWr(fid, fieldname, interpname) -> med_err

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    interpname: char const *const

    """
    return _medfield.MEDfieldInterpWr(fid, fieldname, interpname)

def MEDfieldnInterp(fid: 'med_idt const', fieldname: 'char const *const') -> "char const *const":
    """
    MEDfieldnInterp(fid, fieldname) -> med_int

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const

    """
    return _medfield.MEDfieldnInterp(fid, fieldname)

def MEDfieldInterpInfo(fid: 'med_idt const', fieldname: 'char const *const', interpit: 'int const') -> "char const *const, char *const":
    """
    MEDfieldInterpInfo(fid, fieldname, interpit) -> med_err

    Parameters
    ----------
    fid: med_idt const
    fieldname: char const *const
    interpit: int const

    """
    return _medfield.MEDfieldInterpInfo(fid, fieldname, interpit)
# This file is compatible with both classic and new-style classes.


